django\_notifications.migrations.0002\_notificationconfig module
================================================================

.. automodule:: django_notifications.migrations.0002_notificationconfig
   :members:
   :undoc-members:
   :show-inheritance:
